@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2007-2021 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -142,7 +142,7 @@ mu_acl_destroy (mu_acl_t *pacl)
     free (acl->envv[i]);
   free (acl->envv);
   free (acl);
-  *pacl = acl;
+  *pacl = NULL;
   return 0;
 }
 		   
