@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2019-2021 Free Software Foundation, Inc.
+   Copyright (C) 2019-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -50,7 +50,7 @@ _msg_stream_setup (mu_message_t msg, struct mu_mboxrd_message *dmsg)
   rc = mu_streamref_create_abridged (&stream,
 				     dmsg->mbox->mailbox->stream,
 				     dmsg->message_start + dmsg->from_length,
-				     dmsg->message_end);
+				     dmsg->message_end - 1);
   if (rc == 0)
     rc = mu_message_set_stream (msg, stream, dmsg);
   return rc;
@@ -106,7 +106,7 @@ mboxrd_message_body_scan (struct mu_mboxrd_message *dmsg)
   rc = mu_streamref_create_abridged (&stream,
 				     dmsg->mbox->mailbox->stream,
 				     dmsg->body_start,
-				     dmsg->message_end);
+				     dmsg->message_end - 1);
   if (rc)
     return rc;
 
@@ -129,7 +129,7 @@ mboxrd_message_body_scan (struct mu_mboxrd_message *dmsg)
     return rc;
 
   dmsg->body_lines = body_lines;
-  dmsg->body_size = dmsg->message_end - dmsg->body_start - esc_count + 1;
+  dmsg->body_size = dmsg->message_end - dmsg->body_start - esc_count;
   dmsg->body_from_escaped = esc_count != 0;
   
   dmsg->body_lines_scanned = 1;
@@ -241,7 +241,7 @@ _msg_body_setup (mu_message_t msg, struct mu_mboxrd_message *dmsg)
   rc = mu_streamref_create_abridged (&stream,
 				     dmsg->mbox->mailbox->stream,
 				     dmsg->body_start,
-				     dmsg->message_end);
+				     dmsg->message_end - 1);
   if (rc)
     return rc;
   
@@ -475,9 +475,9 @@ mboxrd_message_copy_with_uid (mu_stream_t dst,
   if (rc)
     return rc;
 
-  rc = mu_stream_copy_nl (dst, src,
-			  dmsg->message_end - dmsg->body_start + 1,
-			  NULL);
+  rc = mu_stream_copy (dst, src,
+		       dmsg->message_end - dmsg->body_start + 1,
+		       NULL);
   if (rc)
     return rc;
 
@@ -540,7 +540,8 @@ env_to_stream (struct mu_mboxrd_message const *dmsg,
       mu_stream_seek (dst, 0, MU_SEEK_CUR, &off);
       ref->from_length = off - ref->message_start;
       ref->env_sender_len = strlen (sender);
-      strncpy (ref->date, date, sizeof (ref->date));
+      ref->date[sizeof (ref->date) - 1] = 0;
+      strncpy (ref->date, date, sizeof (ref->date) - 1);
     }
   
   return rc;
@@ -624,7 +625,7 @@ mu_mboxrd_message_reconstruct (mu_stream_t dest,
     }
   
   if (same_ref)
-    *(struct mu_mboxrd_message *)dmsg = tmp;
+    *dmsg = tmp;
   
   return rc;
 }
