@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,9 @@
 /* The implementation */
 #define	IMPL		"GNU POP3 Daemon"
 
+#define PORT_POP3  110
+#define PORT_POP3S 995
+
 /* APOP password file, without .db or .passwd, which are added based on file
    type automatically */
 #define APOP_PASSFILE_NAME "apop"
@@ -283,12 +286,13 @@ void pop3d_send_payload (mu_stream_t stream, mu_stream_t linestr,
 extern void pop3d_bye           (void);
 extern int pop3d_abquit         (int);
 extern char *pop3d_apopuser     (const char *);
+extern int apop_ok (void);
 extern void process_cleanup     (void);
 
 extern void pop3d_parse_command (char *cmd, char **pcmd, char **parg);
 
-extern RETSIGTYPE pop3d_master_signal  (int);
-extern RETSIGTYPE pop3d_child_signal  (int);
+extern void pop3d_master_signal  (int);
+extern void pop3d_child_signal  (int);
 
 extern int pop3d_stls           (char *, struct pop3d_session *);
 int stls_preflight (mu_m_server_t msrv);
